#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-ant-xml
version:              1.1.9
visibility:           public
id:                   tasty-ant-xml-1.1.9-A74rqbnouSW6wB5REMiZPw
key:                  tasty-ant-xml-1.1.9-A74rqbnouSW6wB5REMiZPw
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  24a3c2e9bce825cfe9449a67a80d6d91
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-ant-xml-1.1.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-ant-xml-1.1.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-ant-xml-1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.9-A74rqbnouSW6wB5REMiZPw
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    generic-deriving-1.14.7-CoIgkO7P5bpIFNJHNdJL3h ghc-prim-0.10.0
    mtl-2.3.1 stm-2.5.1.0 tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
    tasty-1.5.4-GkivOVRJs7F6rF5OuEyJnC transformers-0.6.1.0
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

